.. _readme:

===========================
Client_API_VN main features
===========================

Python applications that use Biolovision/VisioNature (VN) API to:

- download data from VN sites and stores it to a Postgresql database.
- update sightings directly in VN site

Applications are available either as:

- Python modules from PyPI
- Docker images from Docker Hub

They are tested under Linux Ubuntu or Debian. Other Linux
distributions could work. Windows is not tested at all and will
probably not work.

